searchData={"items":[{"type":"module","title":"Whois","doc":"A WHOIS client for Elixir.","ref":"Whois.html"},{"type":"function","title":"Whois.lookup/2","doc":"Queries the appropriate WHOIS server for the domain.\n\nThe domain must be *just* a domain, without any subdomain, protocol or path.\nFor instance, `\"google.com\"` is correct, but not `\"www.google.com\"` or\n`https://google.com`. (If you have a URL, you can use the\n[domainatrex](https://github.com/zensavona/domainatrex) library to extract just the\ndomain.)\n\nReturns `{:ok, record}` if we were able to look up WHOIS records (at the minimum,\nthe date the domain was registered).\n\nNote that for some TLDs (especially country-specific TLDs in the European Union),\nWHOIS information is considered private, and the respective WHOIS servers will return\nlimited information, or even none at all (resulting in `{:error, :no_data_provided}`).\nFor this reason, it's not generally possible to distinguish between cases where the\ndomain is registered (but our WHOIS queries are blocked), versus cases where the domain\nis not registered at all.\n\n#","ref":"Whois.html#lookup/2"},{"type":"function","title":"Options - Whois.lookup/2","doc":"- server: the WHOIS server to query. If not specified, we'll automatically\n  choose the appropriate server.\n\n#","ref":"Whois.html#lookup/2-options"},{"type":"function","title":"Examples - Whois.lookup/2","doc":"iex> {:ok, %Whois.Record{domain: \"google.com\"} = record} = Whois.lookup(\"google.com\")\n    iex> NaiveDateTime.compare(record.expires_at, NaiveDateTime.utc_now())\n    :gt\n\n    iex> Whois.lookup(\"scha.ch\")\n    {:error, :no_data_provided}","ref":"Whois.html#lookup/2-examples"},{"type":"type","title":"Whois.lookup_option/0","doc":"","ref":"Whois.html#t:lookup_option/0"},{"type":"module","title":"Whois.Contact","doc":"Contact information listed in a WHOIS record.","ref":"Whois.Contact.html"},{"type":"type","title":"Whois.Contact.t/0","doc":"","ref":"Whois.Contact.html#t:t/0"},{"type":"module","title":"Whois.Record","doc":"A parsed WHOIS record.","ref":"Whois.Record.html"},{"type":"macro","title":"Whois.Record.is_empty/1","doc":"","ref":"Whois.Record.html#is_empty/1"},{"type":"function","title":"Whois.Record.parse/1","doc":"Parses the raw WHOIS server response in `raw` into a `%Whois.Record{}`.","ref":"Whois.Record.html#parse/1"},{"type":"type","title":"Whois.Record.t/0","doc":"","ref":"Whois.Record.html#t:t/0"},{"type":"module","title":"Whois.Server","doc":"A server we can direct WHOIS requests to.","ref":"Whois.Server.html"},{"type":"function","title":"Whois.Server.all/0","doc":"A map from TLD to the WHOIS server we'll query by default.","ref":"Whois.Server.html#all/0"},{"type":"function","title":"Whois.Server.for/1","doc":"","ref":"Whois.Server.html#for/1"},{"type":"type","title":"Whois.Server.t/0","doc":"","ref":"Whois.Server.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"Super embarrassing compilation fix. 👀","ref":"changelog.html#v0-2-1"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"After a couple years of remaining static, v0.2.0 modernizes the dependencies and bumps the minimum supported Elixir version to Elixir 1.12.\n\nv0.2.0 adds support for the following new TLDs, courtesy of a new maintainer (@s3cur3):\n\n* .se\n* .no\n* .de\n* .im\n* .africa\n* .io\n* .com.au\n* .com.br\n\nIt also adds a new `:status` field to the `%Whois.Record{}` by new contributor @sfusato (👋).\n\n@sfusato also contributed a [fix for a crash when fetching a record](https://github.com/utkarshkukreti/whois.ex/pull/7).\n\n**Full Changelog**: https://github.com/utkarshkukreti/whois.ex/compare/v0.1.1...v0.2.0","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"Whois","doc":"# Whois [![Hex.pm](https://img.shields.io/hexpm/v/whois)](https://hex.pm/packages/whois) [![Build and Test](https://github.com/utkarshkukreti/whois.ex/actions/workflows/elixir-build-and-test.yml/badge.svg)](https://github.com/utkarshkukreti/whois.ex/actions/workflows/elixir-build-and-test.yml) [![Elixir Quality Checks](https://github.com/utkarshkukreti/whois.ex/actions/workflows/elixir-quality-checks.yml/badge.svg)](https://github.com/utkarshkukreti/whois.ex/actions/workflows/elixir-quality-checks.yml) [![Elixir Type Linting](https://github.com/utkarshkukreti/whois.ex/actions/workflows/elixir-dialyzer.yml/badge.svg)](https://github.com/utkarshkukreti/whois.ex/actions/workflows/elixir-dialyzer.yml) [![Code coverage](https://codecov.io/gh/utkarshkukreti/whois.ex/graph/badge.svg?token=Xe9iuK8f63)](https://codecov.io/gh/utkarshkukreti/whois.ex)\n\nA pure Elixir WHOIS client and parser.\n\nWHOIS information includes things like which registrar a domain is registered with,\nwho the contacts for the domain are, when the domain was first registered, when its\nregistration expires, when the DNS record was last updated, and more (but see the \n\"Caveats\" section below).\n\nThis library supports querying the WHOIS server for a large number of top-level\ndomains, including but not limited to:\n\n- `.com`\n- `.net`\n- `.org`\n- `.app`\n- `.dev`\n- `.io`\n- `.info`\n- `.me`\n- `.com.au`\n- `.com.br`\n- `.africa`\n- `.de`\n- `.fr`\n- `.im`\n- `.lv`\n- `.no`\n- `.se`\n- `.ua`","ref":"readme.html"},{"type":"extras","title":"Caveats - Whois","doc":"WHOIS records are not a true standard, and they are first and foremost intended\nfor humans to interpret. Each TLD may return records in a slightly different format,\nand even where the format is consistent, registrars may offer privacy protection\nfor contact information and addresses.\n\nFor some TLDs (especially country-specific TLDs in the European Union), most\nWHOIS information is considered private, and the respective WHOIS servers will return\nlimited information, or even none at all (resulting in `{:error, :no_data_provided}`).\nFor this reason, it's not always possible to distinguish between cases where the\ndomain is registered (but our WHOIS queries are blocked), versus cases where the domain\nis not registered at all.\n\nThe result of all this is that even when you get a success result from `Whois.lookup/1`,\nthe field(s) you're interested in may be `nil`. In some cases this may be because\nwe simply haven't implemented parsing for the TLD in question (`.co.uk` and `.ac.uk`\nare big outstanding examples of this), but more often it's simply the case that the\nTLD's WHOIS server doesn't offer that information.","ref":"readme.html#caveats"},{"type":"extras","title":"Installation - Whois","doc":"Add whois to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:whois, \"~> 0.2\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Whois","doc":"With little exception, `Whois.lookup/1` is the only entry point you'll care about in the library.\n\nIt will choose the appropriate WHOIS server to contact, retrieve the DNS record for your domain,\nand return a parsed version of it.\n\nNote that the domain you pass in must be *just* a domain, without any subdomain, protocol\nor path. For instance, `\"google.com\"` is correct, but not `\"www.google.com\"` or\n`https://google.com`. (If you have a URL, you can use the [domainatrex][] library to \nextract just the domain.)\n\n[domainatrex](https://github.com/zensavona/domainatrex)\n\n```elixir\niex(1)> Whois.lookup(\"google.com\")\n{:ok,\n %Whois.Record{\n   contacts: %{\n     administrator: %Whois.Contact{\n       city: \"Mountain View\",\n       country: \"US\",\n       email: \"dns-admin@google.com\",\n       fax: \"+1.6502530001\",\n       name: \"Domain Administrator\",\n       organization: \"Google LLC\",\n       phone: \"+1.6502530000\",\n       state: \"CA\",\n       street: \"1600 Amphitheatre Parkway,\",\n       zip: \"94043\"\n     },\n     registrant: %Whois.Contact{\n       city: \"Mountain View\",\n       country: \"US\",\n       email: \"dns-admin@google.com\",\n       fax: \"+1.6502530001\",\n       name: \"Domain Administrator\",\n       organization: \"Google LLC\",\n       phone: \"+1.6502530000\",\n       state: \"CA\",\n       street: \"1600 Amphitheatre Parkway,\",\n       zip: \"94043\"\n     },\n     technical: %Whois.Contact{\n       city: \"Mountain View\",\n       country: \"US\",\n       email: \"dns-admin@google.com\",\n       fax: \"+1.6502530001\",\n       name: \"Domain Administrator\",\n       organization: \"Google LLC\",\n       phone: \"+1.6502530000\",\n       state: \"CA\",\n       street: \"1600 Amphitheatre Parkway,\",\n       zip: \"94043\"\n     }\n   },\n   created_at: ~N[1997-09-15 00:00:00],\n   domain: \"google.com\",\n   expires_at: ~N[2020-09-14 04:00:00],\n   nameservers: [\"ns1.google.com\", \"ns2.google.com\", \"ns3.google.com\",\n    \"ns4.google.com\"],\n   raw: \"…\",\n   registrar: \"MarkMonitor, Inc.\",\n   updated_at: ~N[2018-02-21 10:45:07]\n }}\n```","ref":"readme.html#usage"},{"type":"extras","title":"Development - Whois","doc":"#","ref":"readme.html#development"},{"type":"extras","title":"Preparing a PR - Whois","doc":"There are a handful of code quality checks that CI runs. To run them locally, you can use:\n\n```sh\nmix check\n```\n\nThis does *not* adequately test the TCP connection to real Whois servers, because the GitHub Actions IPs are generally blocked by the servers our \"live\" (i.e., full end-to-end) tests rely on. Full full test coverage, you'll need to run `mix test --include live` locally.\n\n#","ref":"readme.html#preparing-a-pr"},{"type":"extras","title":"Updating the list of Whois servers - Whois","doc":"The `priv` directory contains a Makefile that will download the latest TLD reference file from the web and parse it into a structure we can use at compile time. Run it like this:\n\n```sh\ncd priv\nmake clean\nmake tld.json\nmake tld.csv\n```","ref":"readme.html#updating-the-list-of-whois-servers"}],"content_type":"text/markdown"}